# [Changelog]

## v0.0.3  _20170608_
Initial Github publish. 

## v0.0.12  _20200412_
bumped some requirement versions. 
other tweaks to try to get it working

## v0.0.13  _20200412_
manifest includes

## v0.0.14  _20200417_
bumped requirements versions